@@ -1,11 +1,24 @@
 # encoding: utf-8
 class String #:nodoc:
+
+  CRLF = "\r\n"
+  LF   = "\n"
+
+  if RUBY_VERSION >= '1.9'
+    # This 1.9 only regex can save a reasonable amount of time (~20%)
+    # by not matching "\r\n" so the string is returned unchanged in
+    # the common case.
+    CRLF_REGEX = Regexp.new("(?<!\r)\n|\r(?!\n)")
+  else
+    CRLF_REGEX = /\n|\r\n|\r/
+  end
+
   def to_crlf
-    to_str.gsub(/\n|\r\n|\r/) { "\r\n" }
+    to_str.gsub(CRLF_REGEX, CRLF)
   end
 
   def to_lf
-    to_str.gsub(/\n|\r\n|\r/) { "\n" }
+    to_str.gsub(/\r\n|\r/, LF)
   end
 
   unless String.instance_methods(false).map {|m| m.to_sym}.include?(:blank?)
