@@ -5,13 +5,9 @@ module Mail
     include Mail::Utilities
     
     def initialize( string )
-      parser = Mail::ContentDispositionParser.new
-      if tree = parser.parse(cleaned(string))
-        @disposition_type = tree.disposition_type.text_value.downcase
-        @parameters = tree.parameters
-      else
-        raise Mail::Field::ParseError.new(ContentDispositionElement, string, parser.failure_reason)
-      end
+      content_disposition = Mail::Parsers::ContentDispositionParser.new.parse(cleaned(string))
+      @disposition_type = content_disposition.disposition_type
+      @parameters = content_disposition.parameters
     end
     
     def disposition_type
