@@ -22,7 +22,7 @@ module Mail
   #
   class Field
 
-    include Patterns
+    include Utilities
     include Comparable
 
     STRUCTURED_FIELDS = %w[ bcc cc content-description content-disposition
@@ -67,6 +67,10 @@ module Mail
       "content-location" => ContentLocationField,
     }
 
+    FIELD_NAME_MAP = FIELDS_MAP.inject({}) do |map, (field, field_klass)|
+      map.update(field => field_klass::CAPITALIZED_FIELD)
+    end
+
     # Generic Field Exception
     class FieldError < StandardError
     end
@@ -109,16 +113,23 @@ module Mail
     #  Field.new('content-type', ['text', 'plain', {:charset => 'UTF-8'}])
     def initialize(name, value = nil, charset = 'utf-8')
       case
-      when name =~ /:/                  # Field.new("field-name: field data")
-        charset = value unless value.blank?
-        name, value = split(name)
-        create_field(name, value, charset)
-      when name !~ /:/ && value.blank?  # Field.new("field-name")
-        create_field(name, nil, charset)
+      when name.index(COLON)            # Field.new("field-name: field data")
+        @charset = value.blank? ? charset : value
+        @name = name[FIELD_PREFIX]
+        @raw_value = name
+        @value = nil
+      when value.blank?                 # Field.new("field-name")
+        @name = name
+        @value = nil
+        @raw_value = nil
+        @charset = charset
       else                              # Field.new("field-name", "value")
-        create_field(name, value, charset)
+        @name = name
+        @value = value
+        @raw_value = nil
+        @charset = charset
       end
-      return self
+      @name = FIELD_NAME_MAP[@name.to_s.downcase] || @name
     end
 
     def field=(value)
@@ -126,11 +137,12 @@ module Mail
     end
 
     def field
-      @field
+      _, @value = split(@raw_value) if @raw_value && !@value
+      @field ||= create_field(@name, @value, @charset)
     end
 
     def name
-      field.name
+      @name
     end
 
     def value
@@ -138,19 +150,29 @@ module Mail
     end
 
     def value=(val)
-      create_field(name, val, charset)
+      @field = create_field(name, val, @charset)
     end
 
     def to_s
       field.to_s
     end
 
+    def inspect
+      "#<#{self.class.name} 0x#{(object_id * 2).to_s(16)} #{instance_variables.map do |ivar|
+        "#{ivar}=#{instance_variable_get(ivar).inspect}"
+      end.join(" ")}>"
+    end
+
     def update(name, value)
-      create_field(name, value, charset)
+      @field = create_field(name, value, @charset)
     end
 
     def same( other )
-      match_to_s(other.name, field.name)
+      match_to_s(other.name, self.name)
+    end
+
+    def responsible_for?( val )
+      name.to_s.casecmp(val.to_s) == 0
     end
 
     alias_method :==, :same
@@ -182,18 +204,32 @@ module Mail
 
     def split(raw_field)
       match_data = raw_field.mb_chars.match(FIELD_SPLIT)
-      [match_data[1].to_s.mb_chars.strip, match_data[2].to_s.mb_chars.strip]
+      [match_data[1].to_s.mb_chars.strip, match_data[2].to_s.mb_chars.strip.to_s]
     rescue
       STDERR.puts "WARNING: Could not parse (and so ignoring) '#{raw_field}'"
     end
 
+    # 2.2.3. Long Header Fields
+    #
+    #  The process of moving from this folded multiple-line representation
+    #  of a header field to its single line representation is called
+    #  "unfolding". Unfolding is accomplished by simply removing any CRLF
+    #  that is immediately followed by WSP.  Each header field should be
+    #  treated in its unfolded form for further syntactic and semantic
+    #  evaluation.
+    def unfold(string)
+      string.gsub(/[\r\n \t]+/m, ' ')
+    end
+
     def create_field(name, value, charset)
+      value = unfold(value) if value.is_a?(String)
+
       begin
-        self.field = new_field(name, value, charset)
+        new_field(name, value, charset)
       rescue Mail::Field::ParseError => e
-        self.field = Mail::UnstructuredField.new(name, value)
-        self.field.errors << [name, value, e]
-        self.field
+        field = Mail::UnstructuredField.new(name, value)
+        field.errors << [name, value, e]
+        field
       end
     end
 
