@@ -10,8 +10,8 @@ module Mail
     
     def initialize(value = nil, charset = 'utf-8')
       self.charset = charset
-      value = '7bit' if value.to_s =~ /7-bit/i
-      value = '8bit' if value.to_s =~ /8-bit/i
+      value = '7bit' if value.to_s =~ /7-?bits?/i
+      value = '8bit' if value.to_s =~ /8-?bits?/i
       super(CAPITALIZED_FIELD, strip_field(FIELD_NAME, value), charset)
       self.parse
       self
@@ -23,12 +23,6 @@ module Mail
       end
     end
     
-    def tree
-      STDERR.puts("tree is deprecated.  Please use encoding to get parse result\n#{caller}")
-      @element ||= Mail::ContentTransferEncodingElement.new(value)
-      @tree ||= @element.tree
-    end
-    
     def element
       @element ||= Mail::ContentTransferEncodingElement.new(value)
     end
