@@ -47,7 +47,7 @@ module Mail
     end
 
     def address
-      tree.addresses.first
+      address_list.addresses.first
     end
     
     def encoded
