@@ -339,7 +339,7 @@ module Mail #:nodoc:
       # Example:
       #   'Laurent, où sont les tests ?'.mb_chars.upcase.to_s # => "LAURENT, OÙ SONT LES TESTS ?"
       def upcase
-        chars(Unicode.apply_mapping(@wrapped_string), :uppercase_mapping)
+        chars(Unicode.apply_mapping(@wrapped_string, :uppercase_mapping))
       end
 
       # Convert characters in the string to lowercase.
@@ -347,7 +347,7 @@ module Mail #:nodoc:
       # Example:
       #   'VĚDA A VÝZKUM'.mb_chars.downcase.to_s # => "věda a výzkum"
       def downcase
-        chars(Unicode.apply_mapping(@wrapped_string), :lowercase_mapping)
+        chars(Unicode.apply_mapping(@wrapped_string, :lowercase_mapping))
       end
 
       # Converts the first character to uppercase and the remainder to lowercase.
@@ -364,7 +364,7 @@ module Mail #:nodoc:
       #   "ÉL QUE SE ENTERÓ".mb_chars.titleize    # => "Él Que Se Enteró"
       #   "日本語".mb_chars.titleize                 # => "日本語"
       def titleize
-        chars(downcase.to_s.gsub(/\b('?[\S])/u) { Unicode.apply_mapping $1, :uppercase_mapping })
+        chars(downcase.to_s.gsub(/\b('?\S)/u) { Unicode.apply_mapping $1, :uppercase_mapping })
       end
       alias_method :titlecase, :titleize
 
@@ -412,7 +412,7 @@ module Mail #:nodoc:
         chars(Unicode.tidy_bytes(@wrapped_string, force))
       end
 
-       %w(capitalize downcase lstrip reverse rstrip slice strip tidy_bytes upcase).each do |method|
+      %w(capitalize downcase lstrip reverse rstrip slice strip tidy_bytes upcase).each do |method|
         # Only define a corresponding bang method for methods defined in the proxy; On 1.9 the proxy will
         # exclude lstrip!, rstrip! and strip! because they are already work as expected on multibyte strings.
         if public_method_defined?(method)
