@@ -132,15 +132,11 @@ module Mail
         openssl_verify_mode = "OpenSSL::SSL::VERIFY_#{openssl_verify_mode.upcase}".constantize
       end
 
-      if RUBY_VERSION < '1.9.0'
-        openssl_verify_mode
-      else
-        context = Net::SMTP.default_ssl_context
-        context.verify_mode = openssl_verify_mode
-        context.ca_path = settings[:ca_path] if settings[:ca_path]
-        context.ca_file = settings[:ca_file] if settings[:ca_file]
-        context
-      end
+      context = Net::SMTP.default_ssl_context
+      context.verify_mode = openssl_verify_mode
+      context.ca_path = settings[:ca_path] if settings[:ca_path]
+      context.ca_file = settings[:ca_file] if settings[:ca_file]
+      context
     end
   end
 end
