@@ -31,11 +31,13 @@ module Mail
     end
 
     def sort!(order)
-      sorted = self.sort do |a, b|
+      # stable sort should be used to maintain the relative order as the parts are added
+      i = 0;
+      sorted = self.sort_by do |a|
         # OK, 10000 is arbitrary... if anyone actually wants to explicitly sort 10000 parts of a
         # single email message... please show me a use case and I'll put more work into this method,
         # in the meantime, it works :)
-        get_order_value(a, order) <=> get_order_value(b, order)
+        [get_order_value(a, order), i += 1]
       end
       self.clear
       sorted.each { |p| self << p }
@@ -44,7 +46,7 @@ module Mail
   private
 
     def get_order_value(part, order)
-      if part.respond_to?(:content_type)
+      if part.respond_to?(:content_type) && !part[:content_type].nil?
         order.index(part[:content_type].string.downcase) || 10000
       else
         10000
