@@ -26,30 +26,30 @@ describe Mail::Body do
   describe "initialization" do
 
     it "should be instantiated" do
-      doing { Mail::Body.new }.should_not raise_error
+      expect { Mail::Body.new }.not_to raise_error
     end
 
     it "should initialize on a nil value" do
-      doing { Mail::Body.new(nil) }.should_not raise_error
+      expect { Mail::Body.new(nil) }.not_to raise_error
     end
 
     it "should accept text as raw source data" do
       body = Mail::Body.new('this is some text')
-      body.to_s.should eq 'this is some text'
+      expect(body.to_s).to eq 'this is some text'
     end
 
     it "should accept nil as a value and return an empty body" do
       body = Mail::Body.new
-      body.to_s.should eq ''
+      expect(body.to_s).to eq ''
     end
 
     it "should accept an array as the body and join it" do
-      doing { Mail::Body.new(["line one\n", "line two\n"]) }.should_not raise_error
+      expect { Mail::Body.new(["line one\n", "line two\n"]) }.not_to raise_error
     end
 
     it "should accept an array as the body and join it" do
       body = Mail::Body.new(["line one\n", "line two\n"])
-      body.encoded.should eq "line one\r\nline two\r\n"
+      expect(body.encoded).to eq "line one\r\nline two\r\n"
     end
 
   end
@@ -58,29 +58,29 @@ describe Mail::Body do
 
     it "should accept text as raw source data" do
       body = Mail::Body.new('this is some text')
-      body.encoded.should eq 'this is some text'
+      expect(body.encoded).to eq 'this is some text'
     end
 
     it "should set its own encoding to us_ascii if it is ascii only body" do
       body = Mail::Body.new('This is some text')
-      body.charset.should eq 'US-ASCII'
+      expect(body.charset).to eq 'US-ASCII'
     end
 
     it "should allow you to set its encoding" do
       body = Mail::Body.new('')
       body.charset = 'UTF-8'
-      body.charset.should eq 'UTF-8'
+      expect(body.charset).to eq 'UTF-8'
     end
 
     it "should allow you to specify an encoding" do
       body = Mail::Body.new('')
       body.encoding = 'base64'
-      body.encoding.should eq 'base64'
+      expect(body.encoding).to eq 'base64'
     end
 
     it "should convert all new lines to crlf" do
       body = Mail::Body.new("This has \n various \r new \r\n lines")
-      body.encoded.should eq "This has \r\n various \r\n new \r\n lines"
+      expect(body.encoded).to eq "This has \r\n various \r\n new \r\n lines"
     end
 
   end
@@ -89,90 +89,117 @@ describe Mail::Body do
 
     it "should convert all new lines to crlf" do
       body = Mail::Body.new("This has \n various \r new \r\n lines")
-      body.decoded.should eq "This has \n various \n new \n lines"
+      expect(body.decoded).to eq "This has \n various \n new \n lines"
     end
 
     it "should not change a body on decode if not given an encoding type to decode" do
       body = Mail::Body.new("The=3Dbody")
-      body.decoded.should eq "The=3Dbody"
+      expect(body.decoded).to eq "The=3Dbody"
     end
 
     it "should change return the raw text if it does not recognise the encoding" do
       body = Mail::Body.new("The=3Dbody")
       body.encoding = '7bit'
-      body.decoded.should eq "The=3Dbody"
+      expect(body.decoded).to eq "The=3Dbody"
     end
 
     it "should change a body on decode if given an encoding type to decode" do
       body = Mail::Body.new("The=3Dbody")
       body.encoding = 'quoted-printable'
-      body.decoded.should eq "The=body"
+      expect(body.decoded).to eq "The=body"
     end
 
     it "should change a body on decode if given an encoding type to decode" do
       body = Mail::Body.new("VGhlIGJvZHk=\n")
       body.encoding = 'base64'
-      body.decoded.should eq "The body"
+      expect(body.decoded).to eq "The body"
     end
 
   end
 
   describe "splitting up a multipart document" do
+    def assert_split_into(body, pre, epi, parts)
+      body = Mail::Body.new(body)
+      body.split!('----=_Part_2192_32400445')
+      expect(body.parts.size).to eq parts
+      expect(body.preamble).to eq pre
+      expect(body.epilogue).to eq epi
+    end
 
     it "should store the boundary passed in" do
       multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\nThis is a plain text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/html\r\n\r\n<p>This is HTML</p>\r\n------=_Part_2192_32400445--\r\n"
       body = Mail::Body.new(multipart_body)
       body.split!('----=_Part_2192_32400445')
-      body.boundary.should eq '----=_Part_2192_32400445'
+      expect(body.boundary).to eq '----=_Part_2192_32400445'
     end
 
     it "should split at the boundry string given returning two message bodies" do
       multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\nThis is a plain text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/html\r\n\r\n<p>This is HTML</p>\r\n------=_Part_2192_32400445--\r\n"
       body = Mail::Body.new(multipart_body)
-      body.split!('----=_Part_2192_32400445').parts.length.should eq 2
+      expect(body.split!('----=_Part_2192_32400445').parts.length).to eq 2
+    end
+
+    it "should split with missing closing boundary" do
+      multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain\r\n\r\nWhere is the closing boundary...\r\n"
+      assert_split_into(multipart_body, "this is some text", "", 1)
+    end
+
+    it "should not split with empty space after missing closing boundary" do
+      multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain\r\n\r\nWhere is the closing boundary...\r\n------=_Part_2192_32400445\r\n\r\n\r\n\r\n"
+      assert_split_into(multipart_body, "this is some text", "", 1)
+    end
+
+    it "should split with multiple parts and missing closing boundary" do
+      multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain\r\n\r\nExtra part 1\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain\r\n\r\nWhere is the closing boundary...\r\n"
+      assert_split_into(multipart_body, "this is some text", "", 2)
+    end
+
+    it "should ignore blank parts" do
+      multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\n\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain\r\n\r\nWhere is the closing boundary...\r\n"
+      assert_split_into(multipart_body, "this is some text", "", 1)
     end
 
     it "should keep the preamble text as its own preamble" do
       multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\nThis is a plain text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/html\r\n\r\n<p>This is HTML</p>\r\n------=_Part_2192_32400445--\r\n"
       body = Mail::Body.new(multipart_body)
       body.split!('----=_Part_2192_32400445')
-      body.preamble.should eq "this is some text"
+      expect(body.preamble).to eq "this is some text"
     end
 
     it "should return the parts as their own messages" do
       multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\nThis is a plain text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/html\r\n\r\n<p>This is HTML</p>\r\n------=_Part_2192_32400445--\r\n"
       body = Mail::Body.new(multipart_body)
       body.split!('----=_Part_2192_32400445')
-      body.parts[0].class.should eq Mail::Part
-      body.parts[1].class.should eq Mail::Part
+      expect(body.parts[0].class).to eq Mail::Part
+      expect(body.parts[1].class).to eq Mail::Part
     end
 
     it "should return the first part as its own message" do
       multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\nThis is a plain text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/html\r\n\r\n<p>This is HTML</p>\r\n------=_Part_2192_32400445--\r\n"
       body = Mail::Body.new(multipart_body)
       body.split!('----=_Part_2192_32400445')
-      body.parts[0].content_type.should eq "text/plain; charset=ISO-8859-1"
+      expect(body.parts[0].content_type).to eq "text/plain; charset=ISO-8859-1"
     end
 
     it "should return the first part as its own message" do
       multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\nThis is a plain text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/html\r\n\r\n<p>This is HTML</p>\r\n------=_Part_2192_32400445--\r\n"
       body = Mail::Body.new(multipart_body)
       body.split!('----=_Part_2192_32400445')
-      body.parts[1].content_type.should eq "text/html"
+      expect(body.parts[1].content_type).to eq "text/html"
     end
 
     it "should separate out its parts" do
       multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\nThis is a plain text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/html\r\n\r\n<p>This is HTML</p>\r\n------=_Part_2192_32400445--\r\n"
       body = Mail::Body.new(multipart_body)
       body.split!('----=_Part_2192_32400445')
-      body.should be_multipart
+      expect(body).to be_multipart
     end
 
     it "should keep track of its parts" do
       multipart_body = "this is some text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\nThis is a plain text\r\n\r\n------=_Part_2192_32400445\r\nContent-Type: text/html\r\n\r\n<p>This is HTML</p>\r\n------=_Part_2192_32400445--\r\n"
       body = Mail::Body.new(multipart_body)
       body.split!('----=_Part_2192_32400445')
-      body.parts.length.should eq 2
+      expect(body.parts.length).to eq 2
     end
 
     it "should round trip its parts" do
@@ -183,11 +210,11 @@ describe Mail::Body do
       body.epilogue = "And this is the end"
       new_body = Mail::Body.new(body.encoded)
       new_body.split!('----=_Part_2192_32400445')
-      new_body.parts.length.should eq 2
-      new_body.parts[0].decoded.should eq "This is a plain text\n"
-      new_body.parts[1].decoded.should eq "<p>This is HTML</p>"
-      new_body.preamble.should eq "Really! this is some text"
-      new_body.epilogue.should eq "And this is the end"
+      expect(new_body.parts.length).to eq 2
+      expect(new_body.parts[0].decoded).to eq "This is a plain text\n"
+      expect(new_body.parts[1].decoded).to eq "<p>This is HTML</p>"
+      expect(new_body.preamble).to eq "Really! this is some text"
+      expect(new_body.epilogue).to eq "And this is the end"
     end
 
     it "should allow you to change the boundary" do
@@ -197,8 +224,14 @@ describe Mail::Body do
       body.boundary = '------=_MIMEPART'
       new_body = Mail::Body.new(body.encoded)
       new_body.split!('------=_MIMEPART')
-      new_body.parts.length.should eq 2
-      new_body.preamble.should eq "this is some text"
+      expect(new_body.parts.length).to eq 2
+      expect(new_body.preamble).to eq "this is some text"
+    end
+
+    it "should split if boundary is not set" do
+      multipart_body = "\n\n--\nDate: Thu, 01 Aug 2013 15:14:20 +0100\nMime-Version: 1.0\nContent-Type: text/plain\nContent-Transfer-Encoding: 7bit\nContent-Disposition: attachment;\n filename=\"\"\nContent-ID: <51fa6d3cac796_d84e3fe5a58349e025683@local.mail>\n\n\n\n----"
+      body = Mail::Body.new(multipart_body)
+      expect { body.split!(nil) }.not_to raise_error
     end
 
   end
@@ -206,17 +239,17 @@ describe Mail::Body do
   describe "detecting non ascii" do
     it "should say an empty string is all ascii" do
       body = Mail::Body.new
-      body.should be_only_us_ascii
+      expect(body).to be_only_us_ascii
     end
 
     it "should say if a body is ascii" do
       body = Mail::Body.new('This is ASCII')
-      body.should be_only_us_ascii
+      expect(body).to be_only_us_ascii
     end
 
     it "should say if a body is not ascii" do
       body = Mail::Body.new("This is NOT plain text ASCII　− かきくけこ")
-      body.should_not be_only_us_ascii
+      expect(body).not_to be_only_us_ascii
     end
   end
 
@@ -224,8 +257,8 @@ describe Mail::Body do
     it "should allow you to add a part" do
       body = Mail::Body.new('')
       body << Mail::Part.new('')
-      body.parts.length.should eq 1
-      body.should be_multipart
+      expect(body.parts.length).to eq 1
+      expect(body).to be_multipart
     end
 
     it "should allow you to sort the parts" do
@@ -233,12 +266,12 @@ describe Mail::Body do
       body << Mail::Part.new("content-type: text/html\r\nsubject: HTML")
       body << Mail::Part.new("content-type: text/plain\r\nsubject: Plain Text")
       body << Mail::Part.new("content-type: text/enriched\r\nsubject: Enriched")
-      body.parts.length.should eq 3
-      body.should be_multipart
+      expect(body.parts.length).to eq 3
+      expect(body).to be_multipart
       body.sort_parts!
-      body.parts[0].content_type.should eq "text/plain"
-      body.parts[1].content_type.should eq "text/enriched"
-      body.parts[2].content_type.should eq "text/html"
+      expect(body.parts[0].content_type).to eq "text/plain"
+      expect(body.parts[1].content_type).to eq "text/enriched"
+      expect(body.parts[2].content_type).to eq "text/html"
     end
 
     it "should allow you to sort the parts with an arbitrary sort order" do
@@ -247,12 +280,12 @@ describe Mail::Body do
       body << Mail::Part.new("content-type: text/html\r\nsubject: HTML")
       body << Mail::Part.new("content-type: text/plain\r\nsubject: Plain Text")
       body << Mail::Part.new("content-type: text/enriched\r\nsubject: Enriched")
-      body.parts.length.should eq 3
-      body.should be_multipart
+      expect(body.parts.length).to eq 3
+      expect(body).to be_multipart
       body.sort_parts!
-      body.parts[0].content_type.should eq "text/plain"
-      body.parts[1].content_type.should eq "text/html"
-      body.parts[2].content_type.should eq "text/enriched"
+      expect(body.parts[0].content_type).to eq "text/plain"
+      expect(body.parts[1].content_type).to eq "text/html"
+      expect(body.parts[2].content_type).to eq "text/enriched"
     end
 
     it "should allow you to sort the parts with an arbitrary sort order" do
@@ -261,12 +294,12 @@ describe Mail::Body do
       body << Mail::Part.new("content-type: text/plain\r\nsubject: HTML")
       body << Mail::Part.new("content-type: text/html\r\nsubject: Plain Text")
       body << Mail::Part.new("content-type: application/x-yaml\r\nsubject: Enriched")
-      body.parts.length.should eq 3
-      body.should be_multipart
+      expect(body.parts.length).to eq 3
+      expect(body).to be_multipart
       body.sort_parts!
-      body.parts[0].content_type.should eq "application/x-yaml"
-      body.parts[1].content_type.should eq "text/plain"
-      body.parts[2].content_type.should eq "text/html"
+      expect(body.parts[0].content_type).to eq "application/x-yaml"
+      expect(body.parts[1].content_type).to eq "text/plain"
+      expect(body.parts[2].content_type).to eq "text/html"
     end
 
     it "should sort the parts on encode" do
@@ -274,12 +307,12 @@ describe Mail::Body do
       body << Mail::Part.new("content-type: text/html\r\nsubject: HTML")
       body << Mail::Part.new("content-type: text/plain\r\nsubject: Plain Text")
       body << Mail::Part.new("content-type: text/enriched\r\nsubject: Enriched")
-      body.parts.length.should eq 3
-      body.should be_multipart
+      expect(body.parts.length).to eq 3
+      expect(body).to be_multipart
       body.encoded
-      body.parts[0].content_type.should eq "text/plain"
-      body.parts[1].content_type.should eq "text/enriched"
-      body.parts[2].content_type.should eq "text/html"
+      expect(body.parts[0].content_type).to eq "text/plain"
+      expect(body.parts[1].content_type).to eq "text/enriched"
+      expect(body.parts[2].content_type).to eq "text/html"
     end
 
     it "should put the part types it doesn't know about at the end" do
@@ -287,12 +320,12 @@ describe Mail::Body do
       body << Mail::Part.new("content-type: text/html\r\nsubject: HTML")
       body << Mail::Part.new("content-type: text/plain\r\nsubject: Plain Text")
       body << Mail::Part.new("content-type: image/jpeg\r\n")
-      body.parts.length.should eq 3
-      body.should be_multipart
+      expect(body.parts.length).to eq 3
+      expect(body).to be_multipart
       body.encoded
-      body.parts[0].content_type.should eq "text/plain"
-      body.parts[1].content_type.should eq "text/html"
-      body.parts[2].content_type.should eq "image/jpeg"
+      expect(body.parts[0].content_type).to eq "text/plain"
+      expect(body.parts[1].content_type).to eq "text/html"
+      expect(body.parts[2].content_type).to eq "image/jpeg"
     end
 
     it "should allow you to sort the parts recursively" do
@@ -303,14 +336,14 @@ describe Mail::Body do
       body = Mail::Body.new('')
       body << part
       body << Mail::Part.new("content-type: image/jpeg\r\nsubject: JPGEG\r\n\r\nsdkjskjdksjdkjsd")
-      body.parts.length.should eq 2
-      body.should be_multipart
+      expect(body.parts.length).to eq 2
+      expect(body).to be_multipart
       body.sort_parts!
-      body.parts[0].content_type.should match %r{\Amultipart/alternate(;|\Z)}
-      body.parts[1].content_type.should eq "image/jpeg"
-      body.parts[0].parts[0].content_type.should eq "text/plain"
-      body.parts[0].parts[1].content_type.should eq "text/enriched"
-      body.parts[0].parts[2].content_type.should eq "text/html"
+      expect(body.parts[0].content_type).to match %r{\Amultipart/alternate(;|\Z)}
+      expect(body.parts[1].content_type).to eq "image/jpeg"
+      expect(body.parts[0].parts[0].content_type).to eq "text/plain"
+      expect(body.parts[0].parts[1].content_type).to eq "text/enriched"
+      expect(body.parts[0].parts[2].content_type).to eq "text/html"
     end
 
     it "should allow you to sort the parts recursively" do
@@ -321,67 +354,89 @@ describe Mail::Body do
       body = Mail::Body.new('')
       body << part
       body << Mail::Part.new("content-type: image/jpeg\r\nsubject: JPGEG\r\n\r\nsdkjskjdksjdkjsd")
-      body.parts.length.should eq 2
-      body.should be_multipart
+      expect(body.parts.length).to eq 2
+      expect(body).to be_multipart
       body.sort_parts!
-      body.parts[0].content_type.should match %r{\Amultipart/alternate(;|\Z)}
-      body.parts[1].content_type.should eq "image/jpeg"
-      body.parts[0].parts[0].content_type.should eq "text/plain"
-      body.parts[0].parts[1].content_type.should eq "text/enriched"
-      body.parts[0].parts[2].content_type.should eq "text/html"
+      expect(body.parts[0].content_type).to match %r{\Amultipart/alternate(;|\Z)}
+      expect(body.parts[1].content_type).to eq "image/jpeg"
+      expect(body.parts[0].parts[0].content_type).to eq "text/plain"
+      expect(body.parts[0].parts[1].content_type).to eq "text/enriched"
+      expect(body.parts[0].parts[2].content_type).to eq "text/html"
     end
 
+    it "should maintain the relative order of the parts with the same content-type as they are added" do
+      body = Mail::Body.new('');
+      body << Mail::Part.new("content-type: text/html\r\nsubject: HTML_1")
+      body << Mail::Part.new("content-type: image/jpeg\r\nsubject: JPGEG_1\r\n\r\nsdkjskjdksjdkjsd")
+      body << Mail::Part.new("content-type: text/plain\r\nsubject: Plain Text_1")
+      body << Mail::Part.new("content-type: text/enriched\r\nsubject: Enriched_1")
+      body << Mail::Part.new("content-type: text/html\r\nsubject: HTML_2")
+      body << Mail::Part.new("content-type: text/plain\r\nsubject: Plain Text_2")
+      body << Mail::Part.new("content-type: image/jpeg\r\nsubject: JPGEG_2\r\n\r\nsdkjskjdksjdkjsd")
+      body << Mail::Part.new("content-type: text/enriched\r\nsubject: Enriched_2")
+      expect(body.parts.length).to eq 8
+      expect(body).to be_multipart
+      body.sort_parts!
+      expect(body.parts[0].subject).to eq "Plain Text_1"
+      expect(body.parts[1].subject).to eq "Plain Text_2"
+      expect(body.parts[2].subject).to eq "Enriched_1"
+      expect(body.parts[3].subject).to eq "Enriched_2"
+      expect(body.parts[4].subject).to eq "HTML_1"
+      expect(body.parts[5].subject).to eq "HTML_2"
+      expect(body.parts[6].subject).to eq "JPGEG_1"
+      expect(body.parts[7].subject).to eq "JPGEG_2"
+    end
   end
 
   describe "matching" do
 
     it "should still equal itself" do
       body = Mail::Body.new('The body')
-      body.should eq body
+      expect(body).to eq body
     end
 
     it "should match on the body part decoded if given a string to ==" do
       body = Mail::Body.new('The body')
-      (body == 'The body').should be_true
+      expect(body == 'The body').to be_truthy
     end
 
     it "should match on the body part decoded if given a string to ==" do
       body = Mail::Body.new("VGhlIGJvZHk=\n")
       body.encoding = 'base64'
-      (body == "The body").should be_true
+      expect(body == "The body").to be_truthy
     end
 
     it "should match on the body part decoded if given a string to =~" do
       body = Mail::Body.new('The body')
-      (body =~ /The/).should eq 0
+      expect(body =~ /The/).to eq 0
     end
 
     it "should match on the body part decoded if given a string to ==" do
       body = Mail::Body.new("VGhlIGJvZHk=\n")
       body.encoding = 'base64'
-      (body =~ /The/).should eq 0
+      expect(body =~ /The/).to eq 0
     end
 
     it "should match on the body part decoded if given a string to match" do
       body = Mail::Body.new('The body')
-      (body.match(/The/))[0].should eq 'The'
+      expect((body.match(/The/))[0]).to eq 'The'
     end
 
     it "should match on the body part decoded if given a string to match" do
       body = Mail::Body.new("VGhlIGJvZHk=\n")
       body.encoding = 'base64'
-      (body.match(/The/))[0].should eq 'The'
+      expect((body.match(/The/))[0]).to eq 'The'
     end
 
     it "should match on the body part decoded if given a string to include?" do
       body = Mail::Body.new('The Body')
-      body.should include('The')
+      expect(body).to include('The')
     end
 
     it "should match on the body part decoded if given a string to include?" do
       body = Mail::Body.new("VGhlIGJvZHk=\n")
       body.encoding = 'base64'
-      body.should include('The')
+      expect(body).to include('The')
     end
   end
 
@@ -390,7 +445,7 @@ describe Mail::Body do
       body = Mail::Body.new("あいうえお\n")
       body.charset = 'iso-2022-jp'
       expect = (RUBY_VERSION < '1.9') ? "あいうえお\r\n" : "\e$B$\"$$$&$($*\e(B\r\n"
-      body.encoded.should eq expect
+      expect(body.encoded).to eq expect
     end
   end
 end
