@@ -6,7 +6,7 @@ describe "mail encoding" do
   it "should allow you to assign a mail wide charset" do
     mail = Mail.new
     mail.charset = 'utf-8'
-    mail.charset.should eq 'utf-8'
+    expect(mail.charset).to eq 'utf-8'
   end
 
   describe "using default encoding" do
@@ -15,7 +15,7 @@ describe "mail encoding" do
       mail.charset = 'utf-8'
       mail.subject = "This is あ string"
       result = "Subject: =?UTF-8?Q?This_is_=E3=81=82_string?=\r\n"
-      mail[:subject].encoded.should eq result
+      expect(mail[:subject].encoded).to eq result
     end
 
     it "should allow you to send in unencoded strings to address fields and encode them" do
@@ -23,7 +23,7 @@ describe "mail encoding" do
       mail.charset = 'utf-8'
       mail.to = "Mikel Lindsああr <mikel@test.lindsaar.net>"
       result = "To: Mikel =?UTF-8?B?TGluZHPjgYLjgYJy?= <mikel@test.lindsaar.net>\r\n"
-      mail[:to].encoded.should eq result
+      expect(mail[:to].encoded).to eq result
     end
 
     it "should allow you to send in unencoded strings to address fields and encode them" do
@@ -31,7 +31,7 @@ describe "mail encoding" do
       mail.charset = 'utf-8'
       mail.to = "あdあ <ada@test.lindsaar.net>"
       result = "To: =?UTF-8?B?44GCZOOBgg==?= <ada@test.lindsaar.net>\r\n"
-      mail[:to].encoded.should eq result
+      expect(mail[:to].encoded).to eq result
     end
 
     it "should allow you to send in multiple unencoded strings to address fields and encode them" do
@@ -39,7 +39,7 @@ describe "mail encoding" do
       mail.charset = 'utf-8'
       mail.to = ["Mikel Lindsああr <mikel@test.lindsaar.net>", "あdあ <ada@test.lindsaar.net>"]
       result = "To: Mikel =?UTF-8?B?TGluZHPjgYLjgYJy?= <mikel@test.lindsaar.net>, \r\n\s=?UTF-8?B?44GCZOOBgg==?= <ada@test.lindsaar.net>\r\n"
-      mail[:to].encoded.should eq result
+      expect(mail[:to].encoded).to eq result
     end
 
     it "should allow you to send unquoted non us-ascii strings, with spaces in them" do
@@ -47,7 +47,7 @@ describe "mail encoding" do
       mail.charset = 'utf-8'
       mail.to = ["Foo áëô îü <extended@example.net>"]
       result = "To: Foo =?UTF-8?B?w6HDq8O0?= =?UTF-8?B?IMOuw7w=?= <extended@example.net>\r\n"
-      mail[:to].encoded.should eq result
+      expect(mail[:to].encoded).to eq result
     end
 
     it "should allow you to send in multiple unencoded strings to any address field" do
@@ -56,7 +56,7 @@ describe "mail encoding" do
       ['To', 'From', 'Cc', 'Reply-To'].each do |field|
         mail.send("#{field.downcase.gsub("-", '_')}=", ["Mikel Lindsああr <mikel@test.lindsaar.net>", "あdあ <ada@test.lindsaar.net>"])
         result = "#{field}: Mikel =?UTF-8?B?TGluZHPjgYLjgYJy?= <mikel@test.lindsaar.net>, \r\n\s=?UTF-8?B?44GCZOOBgg==?= <ada@test.lindsaar.net>\r\n"
-        mail[field].encoded.should eq result
+        expect(mail[field].encoded).to eq result
       end
     end
 
@@ -65,7 +65,7 @@ describe "mail encoding" do
       mail.charset = 'utf-8'
       mail.to = "test1@lindsaar.net, group: test2@lindsaar.net, me@lindsaar.net;"
       result = "To: test1@lindsaar.net, \r\n\sgroup: test2@lindsaar.net, \r\n\sme@lindsaar.net;\r\n"
-      mail[:to].encoded.should eq result
+      expect(mail[:to].encoded).to eq result
     end
 
     it "should handle groups with funky characters" do
@@ -73,7 +73,7 @@ describe "mail encoding" do
       mail.charset = 'utf-8'
       mail.to = '"Mikel Lindsああr" <test1@lindsaar.net>, group: "あdあ" <test2@lindsaar.net>, me@lindsaar.net;'
       result = "To: =?UTF-8?B?TWlrZWwgTGluZHPjgYLjgYJy?= <test1@lindsaar.net>, \r\n\sgroup: =?UTF-8?B?44GCZOOBgg==?= <test2@lindsaar.net>, \r\n\sme@lindsaar.net;\r\n"
-      mail[:to].encoded.should eq result
+      expect(mail[:to].encoded).to eq result
     end
 
     describe "quoting token safe chars" do
@@ -82,32 +82,31 @@ describe "mail encoding" do
         mail = Mail.new
         mail.charset = 'utf-8'
         mail.to = 'Mikel Lindsaar <mikel@test.lindsaar.net>'
-        mail[:to].encoded.should eq %{To: Mikel Lindsaar <mikel@test.lindsaar.net>\r\n}
+        expect(mail[:to].encoded).to eq %{To: Mikel Lindsaar <mikel@test.lindsaar.net>\r\n}
       end
 
       it "should not quote the display name if already quoted" do
         mail = Mail.new
         mail.charset = 'utf-8'
         mail.to = '"Mikel Lindsaar" <mikel@test.lindsaar.net>'
-        mail[:to].encoded.should eq %{To: Mikel Lindsaar <mikel@test.lindsaar.net>\r\n}
+        expect(mail[:to].encoded).to eq %{To: Mikel Lindsaar <mikel@test.lindsaar.net>\r\n}
       end
 
     end
 
     describe "quoting token unsafe chars" do
       it "should quote the display name" do
-        pending
         mail = Mail.new
         mail.charset = 'utf-8'
         mail.to = "Mikel @ me Lindsaar <mikel@test.lindsaar.net>"
-        mail[:to].encoded.should eq %{To: "Mikel @ me Lindsaar" <mikel@test.lindsaar.net>\r\n}
+        expect(mail[:to].encoded).to eq %{To: "Mikel @ me Lindsaar" <mikel@test.lindsaar.net>\r\n}
       end
 
       it "should preserve quotes needed from the user and not double quote" do
         mail = Mail.new
         mail.charset = 'utf-8'
         mail.to = %{"Mikel @ me Lindsaar" <mikel@test.lindsaar.net>}
-        mail[:to].encoded.should eq %{To: "Mikel @ me Lindsaar" <mikel@test.lindsaar.net>\r\n}
+        expect(mail[:to].encoded).to eq %{To: "Mikel @ me Lindsaar" <mikel@test.lindsaar.net>\r\n}
       end
     end
   end
@@ -125,7 +124,7 @@ describe "mail encoding" do
         string.force_encoding('ISO8859-1')
         result.force_encoding('ISO8859-1')
       end
-      result.should eq string
+      expect(result).to eq string
     end
 
     it "should allow you to send in unencoded strings to address fields and encode them" do
@@ -140,7 +139,7 @@ describe "mail encoding" do
         string.force_encoding('ISO8859-1')
         result.force_encoding('ISO8859-1')
       end
-      result.should eq string
+      expect(result).to eq string
     end
 
     it "should allow you to send in multiple unencoded strings to address fields and encode them" do
@@ -155,7 +154,7 @@ describe "mail encoding" do
         string.force_encoding('ISO8859-1')
         result.force_encoding('ISO8859-1')
       end
-      result.should eq string
+      expect(result).to eq string
     end
 
     it "should allow you to send in multiple unencoded strings to any address field" do
@@ -171,7 +170,7 @@ describe "mail encoding" do
           string.force_encoding('ISO8859-1')
           result.force_encoding('ISO8859-1')
         end
-        result.should eq string
+        expect(result).to eq string
       end
     end
   end
@@ -183,16 +182,16 @@ describe "mail encoding" do
     part.charset = "ISO-8859-1"
     part.body = "blah"
     mail.add_part(part)
-    mail.parts[0].content_type.should eq "text/html; charset=ISO-8859-1"
+    expect(mail.parts[0].content_type).to eq "text/html; charset=ISO-8859-1"
   end
 
   it "should skip invalid characters" do
     m = Mail.new
     m['Subject'] = Mail::SubjectField.new("=?utf-8?Q?Hello_=96_World?=")
     if RUBY_VERSION > '1.9'
-      lambda { m.subject.should be_valid_encoding }.should_not raise_error
+      expect { expect(m.subject).to be_valid_encoding }.not_to raise_error
     else
-      m.subject.should eq "Hello  World"
+      expect(m.subject).to eq "Hello  World"
     end
   end
 end
