@@ -6,19 +6,19 @@ describe Mail::CommentsField do
   # comments        =       "Comments:" unstructured CRLF
   
   it "should initialize" do
-    doing { Mail::CommentsField.new("this is a comment") }.should_not raise_error
+    expect { Mail::CommentsField.new("this is a comment") }.not_to raise_error
   end
 
   it "should accept a string with the field name" do
     t = Mail::CommentsField.new('Comments: this is a comment')
-    t.name.should eq 'Comments'
-    t.value.should eq 'this is a comment'
+    expect(t.name).to eq 'Comments'
+    expect(t.value).to eq 'this is a comment'
   end
 
   it "should accept a string with the field name" do
     t = Mail::CommentsField.new('this is a comment')
-    t.name.should eq 'Comments'
-    t.value.should eq 'this is a comment'
+    expect(t.name).to eq 'Comments'
+    expect(t.value).to eq 'this is a comment'
   end
   
   
