@@ -4,11 +4,11 @@ require 'spec_helper'
 describe "mail" do
   
   it "should be able to be instantiated" do
-    doing { Mail }.should_not raise_error
+    expect { Mail }.not_to raise_error
   end
   
   it "should be able to make a new email" do
-    Mail.new.class.should eq Mail::Message
+    expect(Mail.new.class).to eq Mail::Message
   end
   
   it "should accept headers and body" do
@@ -19,16 +19,16 @@ describe "mail" do
       subject 'Hello there Mikel'
       body    'This is a body of text'
     end
-    message.from.should      eq ['mikel@me.com']
-    message.to.should        eq ['mikel@you.com']
-    message.subject.should   eq 'Hello there Mikel'
-    message.body.to_s.should eq 'This is a body of text'
+    expect(message.from).to      eq ['mikel@me.com']
+    expect(message.to).to        eq ['mikel@you.com']
+    expect(message.subject).to   eq 'Hello there Mikel'
+    expect(message.body.to_s).to eq 'This is a body of text'
   end
 
   it "should read a file" do
     wrap_method = Mail.read(fixture('emails', 'plain_emails', 'raw_email.eml')).to_s
     file_method = Mail.new(File.open(fixture('emails', 'plain_emails', 'raw_email.eml'), 'rb', &:read)).to_s
-    wrap_method.should eq file_method
+    expect(wrap_method).to eq file_method
   end
 
 end
