@@ -6,12 +6,12 @@ describe "multibyte/chars" do
 
   it "should upcase" do
     chars = Chars.new('Laurent, où sont les tests ?')
-    chars.upcase.should == "LAURENT, OÙ SONT LES TESTS ?"
+    expect(chars.upcase).to eq("LAURENT, OÙ SONT LES TESTS ?")
   end
 
   it "should downcase" do
     chars = Chars.new('VĚDA A VÝZKUM')
-    chars.downcase.should == "věda a výzkum"
+    expect(chars.downcase).to eq("věda a výzkum")
   end
 end
 
